Range-v3: ranges::v3::concepts::Iterator Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::concepts::Iterator Struct Reference
Inheritance diagram for ranges::v3::concepts::Iterator:

## Public Member Functions
template<typename I >
auto | requires_ (I i) -> decltype(concepts::valid_expr(((void) *i, 42)))
Public Member Functions inherited from ranges::v3::concepts::refines< WeaklyIncrementable, Copyable >
void | requires_ ()

## Additional Inherited Members
Public Types inherited from ranges::v3::concepts::refines< WeaklyIncrementable, Copyable >
using | base_concepts_t = meta::list< Concepts... >